package org.mmga.clubs.controller;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.mmga.clubs.entities.BaseResponse;
import org.mmga.clubs.entities.user.User;
import org.mmga.clubs.entities.user.UserLoginVo;
import org.mmga.clubs.entities.user.UserRegVo;
import org.mmga.clubs.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/user")
@Tag(name = "用户", description = "用户相关接口")
@Slf4j
public class UserController {
    private final UserService service;
    @Autowired
    public UserController(UserService userService){
        this.service = userService;
    }
    @PostMapping("/login")
    @Operation(description = "用户登录", responses = {@ApiResponse(description = "返回是否登录成功", responseCode = "200")})
    public BaseResponse<User> login(@RequestBody UserLoginVo user, HttpServletResponse response){
        return service.login(user, response);
    }
    @PutMapping("/create")
    @Operation(description = "创建用户", responses = {@ApiResponse(description = "返回创建后的用户")})
    public BaseResponse<User> createUser(@RequestBody UserRegVo user, HttpServletResponse response){
        return service.createUser(user, response);
    }
}
